@@ -4,7 +4,9 @@ use MRO::Compat 'c3';
 
 package WebService::Shippo::Address;
 require WebService::Shippo::Request;
+use Carp              ( 'confess' );
 use Params::Callbacks ( 'callbacks' );
+use Scalar::Util      ( 'blessed' );
 use base (
     'WebService::Shippo::Resource',
     'WebService::Shippo::Creator',
@@ -17,10 +19,17 @@ sub api_resource { 'addresses' }
 
 sub validate
 {
-    my ( $callbacks, $invocant, $id, @params ) = &callbacks;
-    my $url = $invocant->url( "$id/validate" );
+    my ( $callbacks, $invocant, $object_id, @params ) = &callbacks;
+    $object_id = $invocant->{object_id}
+        if blessed( $invocant ) && !$object_id;
+    confess 'Expected an object id'
+        unless $object_id;
+    my $url = $invocant->url( "$object_id/validate" );
     my $response = WebService::Shippo::Request->get( $url, @params );
-    return $invocant->construct_from( $response, $callbacks );
+    my $upd = $invocant->construct_from( $response, $callbacks );
+    return $upd
+        unless blessed( $invocant ) && $invocant->id eq $object_id;
+    $invocant->refresh_from( $upd );
 }
 
 package    # Hide from PAUSE
