@@ -18,11 +18,18 @@ use base (
 
 sub api_resource { 'shipments' }
 
-sub request_get_shipping_rates
+sub get_shipping_rates
 {
     my ( $callbacks, $invocant, $shipment_id, @params ) = &callbacks;
     confess "Expected a shipment id"
         unless $shipment_id;
+    my $shipment;
+    if ( $invocant->is_same_object($shipment_id) ) {
+        $shipment = $invocant;
+    }
+    else {
+        $shipment = WebService::Shippo::Shipment->fetch( $shipment_id );
+    }
     my $currency;
     if ( @params && @params % 2 ) {
         ( $currency, @params ) = @params;
@@ -32,6 +39,15 @@ sub request_get_shipping_rates
     $rates_url .= "/$currency"
         if $currency;
     $rates_url = $invocant->url( $rates_url );
+    my $async;
+    my %params = @params;
+    $async = delete( $params{async} )
+        if exists $params{async};
+    @params = %params;
+    unless ( $async ) {
+        WebService::Shippo::Request->get( $rates_url, @params );
+        $shipment->wait_if_status_in( 'QUEUED', 'WAITING' );
+    }
     my $response = WebService::Shippo::Request->get( $rates_url, @params );
     unshift @$callbacks, callback {
         return unless @_;
@@ -43,24 +59,6 @@ sub request_get_shipping_rates
     return $rates;
 }
 
-sub get_shipping_rates
-{
-    my ( $callbacks, $invocant, $shipment_id, @params ) = &callbacks;
-    my $shipment;
-    if (   blessed( $invocant )
-        && $invocant->id
-        && $invocant->id eq $shipment_id )
-    {
-        $shipment = $invocant;
-    }
-    else {
-        $shipment = WebService::Shippo::Shipment->fetch( $shipment_id );
-    }
-    &request_get_shipping_rates;
-    $shipment->wait_if_status_in( 'QUEUED', 'WAITING' );
-    return &request_get_shipping_rates;
-}
-
 package    # Hide from PAUSE
     WebService::Shippo::ShipmentList;
 use base ( 'WebService::Shippo::ObjectList' );
