@@ -17,20 +17,18 @@ sub api_resource { 'transactions' }
 
 sub get_shipping_label
 {
-    my ( $invocant, $transaction_id ) = @_;
+    my ( $invocant, $transaction_id, %params ) = @_;
     confess "Expected a transaction id"
         unless $transaction_id;
     my $transaction;
-    if (   blessed( $invocant )
-        && $invocant->id
-        && $invocant->id eq $transaction_id )
-    {
+    if ( $invocant->is_same_object($transaction_id) ) {
         $transaction = $invocant;
     }
     else {
         $transaction = WebService::Shippo::Transaction->fetch( $transaction_id );
     }
-    $transaction->wait_if_status_in( 'QUEUED', 'WAITING' );
+    $transaction->wait_if_status_in( 'QUEUED', 'WAITING' )
+        unless $params{async};
     return $transaction->label_url;
 }
 
